@@ -1820,7 +1820,8 @@ class MSDialect(default.DefaultDialect):
 
     ischema_names = ischema_names
 
-    supports_native_boolean = True
+    supports_native_boolean = False
+    non_native_boolean_check_constraint = False
     supports_unicode_binds = True
     postfetch_lastrowid = True
 
@@ -1896,6 +1897,8 @@ class MSDialect(default.DefaultDialect):
             raise NotImplementedError(
                 "Can't fetch isolation level prior to SQL Server 2005")
 
+        last_error = None
+
         views = ("sys.dm_exec_sessions", "sys.dm_pdw_nodes_exec_sessions")
         for view in views:
             cursor = connection.cursor()
@@ -1913,19 +1916,22 @@ class MSDialect(default.DefaultDialect):
                   """ % view)
                 val = cursor.fetchone()[0]
             except self.dbapi.Error as err:
+                # Python3 scoping rules
+                last_error = err
                 continue
             else:
                 return val.upper()
             finally:
                 cursor.close()
+        else:
+            util.warn(
+                "Could not fetch transaction isolation level, "
+                "tried views: %s; final error was: %s" % (views, last_error))
 
-        util.warn(
-            "Could not fetch transaction isolation level, "
-            "tried views: %s; final error was: %s" % (views, err))
-        raise NotImplementedError(
-            "Can't fetch isolation level on this particular "
-            "SQL Server version"
-        )
+            raise NotImplementedError(
+                "Can't fetch isolation level on this particular "
+                "SQL Server version"
+            )
 
     def initialize(self, connection):
         super(MSDialect, self).initialize(connection)
@@ -2245,6 +2251,8 @@ class MSDialect(default.DefaultDialect):
                                 C.c.constraint_name == RR.c.constraint_name,
                                 R.c.constraint_name ==
                                 RR.c.unique_constraint_name,
+                                R.c.constraint_schema ==
+                                RR.c.unique_constraint_schema,
                                 C.c.ordinal_position == R.c.ordinal_position
                                 ),
                        order_by=[RR.c.constraint_name, R.c.ordinal_position]
