@@ -9,38 +9,41 @@
 
 import json
 import logging
+import os
 from abc import ABCMeta, abstractmethod, abstractproperty
-import six
-from socket import error as SOCKETErrorException
-from smtplib import SMTPConnectError, SMTPResponseException,\
-    SMTPServerDisconnected, SMTPDataError,SMTPHeloError, SMTPException, \
+from smtplib import SMTPConnectError, SMTPResponseException, \
+    SMTPServerDisconnected, SMTPDataError, SMTPHeloError, SMTPException, \
     SMTPAuthenticationError, SMTPSenderRefused, SMTPRecipientsRefused
-from flask import current_app, render_template, url_for, make_response, flash,\
-    Response, request, after_this_request, redirect
-from flask_babel import gettext
-from flask_login import current_user, login_required
-from flask_security.decorators import anonymous_user_required
+from socket import error as SOCKETErrorException
+
+import six
+from flask import current_app, render_template, url_for, make_response, \
+    flash, Response, request, after_this_request, redirect
+from flask_babelex import gettext
 from flask_gravatar import Gravatar
+from flask_login import current_user, login_required
+from flask_security.changeable import change_user_password
+from flask_security.decorators import anonymous_user_required
+from flask_security.recoverable import reset_password_token_status, \
+    generate_reset_password_token, update_password
+from flask_security.signals import reset_password_instructions_sent
+from flask_security.utils import config_value, do_flash, get_url, \
+    get_message, slash_url_suffix, login_user, send_mail
+from flask_security.views import _security, _commit, _render_json, _ctx
+from werkzeug.datastructures import MultiDict
+
+import config
+from pgadmin import current_blueprint
 from pgadmin.settings import get_setting
 from pgadmin.utils import PgAdminModule
 from pgadmin.utils.ajax import make_json_response
 from pgadmin.utils.preferences import Preferences
-from werkzeug.datastructures import MultiDict
-from flask_security.views import _security, _commit, _render_json, _ctx
-from flask_security.changeable import change_user_password
-from flask_security.recoverable import reset_password_token_status, \
-    generate_reset_password_token, update_password
-from flask_security.utils import config_value, do_flash, get_url, get_message,\
-    slash_url_suffix, login_user, send_mail
-from flask_security.signals import reset_password_instructions_sent
-
-
-import config
-from pgadmin import current_blueprint
+from pgadmin.browser.register_browser_preferences import \
+    register_browser_preferences
 
 try:
     import urllib.request as urlreq
-except:
+except ImportError as e:
     import urllib2 as urlreq
 
 MODULE_NAME = 'browser'
@@ -51,14 +54,19 @@ class BrowserModule(PgAdminModule):
 
     def get_own_stylesheets(self):
         stylesheets = []
+        context_menu_file = 'vendor/jQuery-contextMenu/' \
+                            'jquery.contextMenu.min.css'
+        wcdocker_file = 'vendor/wcDocker/wcDocker.min.css'
+        if current_app.debug:
+            context_menu_file = 'vendor/jQuery-contextMenu/' \
+                                'jquery.contextMenu.css'
+            wcdocker_file = 'vendor/wcDocker/wcDocker.css'
         # Add browser stylesheets
         for (endpoint, filename) in [
             ('static', 'vendor/codemirror/codemirror.css'),
             ('static', 'vendor/codemirror/addon/dialog/dialog.css'),
-            ('static', 'vendor/jQuery-contextMenu/jquery.contextMenu.css' if current_app.debug
-            else 'vendor/jQuery-contextMenu/jquery.contextMenu.min.css'),
-            ('static', 'vendor/wcDocker/wcDocker.css' if current_app.debug
-            else 'vendor/wcDocker/wcDocker.min.css'),
+            ('static', context_menu_file),
+            ('static', wcdocker_file),
             ('browser.static', 'css/browser.css'),
             ('browser.static', 'vendor/aciTree/css/aciTree.css')
         ]:
@@ -82,9 +90,9 @@ class BrowserModule(PgAdminModule):
             'name': 'jqueryui.position',
             'path': url_for(
                 'static',
-                filename='vendor/jQuery-contextMenu/jquery.ui.position' if \
-                    current_app.debug else \
-                    'vendor/jQuery-contextMenu/jquery.ui.position.min'
+                filename='vendor/jQuery-contextMenu/jquery.ui.position' if
+                current_app.debug else
+                'vendor/jQuery-contextMenu/jquery.ui.position.min'
             ),
             'deps': ['jquery'],
             'exports': 'jQuery.ui.position',
@@ -94,9 +102,9 @@ class BrowserModule(PgAdminModule):
             'name': 'jquery.contextmenu',
             'path': url_for(
                 'static',
-                filename='vendor/jQuery-contextMenu/jquery.contextMenu' if \
-                    current_app.debug else \
-                    'vendor/jQuery-contextMenu/jquery.contextMenu.min'
+                filename='vendor/jQuery-contextMenu/jquery.contextMenu' if
+                current_app.debug else
+                'vendor/jQuery-contextMenu/jquery.contextMenu.min'
             ),
             'deps': ['jquery', 'jqueryui.position'],
             'exports': 'jQuery.contextMenu',
@@ -166,7 +174,8 @@ class BrowserModule(PgAdminModule):
         for name, script in [
             ['pgadmin.browser', 'js/browser'],
             ['pgadmin.browser.endpoints', 'js/endpoints'],
-            ['pgadmin.browser.error', 'js/error']]:
+            ['pgadmin.browser.error', 'js/error']
+        ]:
             scripts.append({
                 'name': name,
                 'path': url_for('browser.index') + script,
@@ -176,7 +185,8 @@ class BrowserModule(PgAdminModule):
         for name, script in [
             ['pgadmin.browser.node', 'js/node'],
             ['pgadmin.browser.messages', 'js/messages'],
-            ['pgadmin.browser.collection', 'js/collection']]:
+            ['pgadmin.browser.collection', 'js/collection']
+        ]:
             scripts.append({
                 'name': name,
                 'path': url_for('browser.index') + script,
@@ -187,7 +197,8 @@ class BrowserModule(PgAdminModule):
         for name, end in [
             ['pgadmin.browser.menu', 'js/menu'],
             ['pgadmin.browser.panel', 'js/panel'],
-            ['pgadmin.browser.frame', 'js/frame']]:
+            ['pgadmin.browser.frame', 'js/frame']
+        ]:
             scripts.append({
                 'name': name, 'path': url_for('browser.static', filename=end),
                 'preloaded': True})
@@ -203,16 +214,7 @@ class BrowserModule(PgAdminModule):
         return scripts
 
     def register_preferences(self):
-        self.show_system_objects = self.preference.register(
-            'display', 'show_system_objects',
-            gettext("Show system objects?"), 'boolean', False,
-            category_label=gettext('Display')
-        )
-        self.table_row_count_threshold = self.preference.register(
-            'properties', 'table_row_count_threshold',
-            gettext("Count rows if estimated less than"), 'integer', 2000,
-            category_label=gettext('Properties')
-        )
+        register_browser_preferences(self)
 
     def get_exposed_url_endpoints(self):
         """
@@ -221,6 +223,7 @@ class BrowserModule(PgAdminModule):
         """
         return ['browser.index', 'browser.nodes']
 
+
 blueprint = BrowserModule(MODULE_NAME, __name__)
 
 
@@ -255,7 +258,8 @@ class BrowserPluginModule(PgAdminModule):
         Every module extended from this will be identified as 'NODE-<type>'.
 
         Also, create a preference 'show_node_<type>' to fetch whether it
-        can be shown in the browser or not. Also,  refer to the browser-preference.
+        can be shown in the browser or not. Also,  refer to the
+        browser-preference.
         """
         kwargs.setdefault("url_prefix", self.node_path)
         kwargs.setdefault("static_url_path", '/static')
@@ -309,7 +313,8 @@ class BrowserPluginModule(PgAdminModule):
         if self.module_use_template_javascript:
             scripts.extend([{
                 'name': 'pgadmin.node.%s' % self.node_type,
-                'path': url_for('browser.index') + '%s/module' % self.node_type,
+                'path': url_for('browser.index') +
+                        '%s/module' % self.node_type,
                 'when': self.script_load,
                 'is_template': True
             }])
@@ -317,7 +322,8 @@ class BrowserPluginModule(PgAdminModule):
             scripts.extend([{
                 'name': 'pgadmin.node.%s' % self.node_type,
                 'path': url_for(
-                    '%s.static'% self.name, filename=('js/%s' % self.node_type)
+                    '%s.static' % self.name,
+                    filename=('js/%s' % self.node_type)
                 ),
                 'when': self.script_load,
                 'is_template': False
@@ -329,7 +335,7 @@ class BrowserPluginModule(PgAdminModule):
         return scripts
 
     def generate_browser_node(
-            self, node_id, parent_id, label, icon, inode, node_type, **kwargs
+        self, node_id, parent_id, label, icon, inode, node_type, **kwargs
     ):
         """
         Helper function to create a browser node for this particular subnode.
@@ -432,7 +438,8 @@ class BrowserPluginModule(PgAdminModule):
     @property
     def show_node(self):
         """
-        A proper to check to show node for this module on the browser tree or not.
+        A proper to check to show node for this module on the browser tree or
+        not.
 
         Relies on show_node preference object, otherwise on the SHOW_ON_BROWSER
         default value.
@@ -459,14 +466,16 @@ class BrowserPluginModule(PgAdminModule):
         Sets the browser_preference, show_system_objects, show_node preference
         objects for this submodule.
         """
-        # Add the node informaton for browser, not in respective node preferences
+        # Add the node informaton for browser, not in respective node
+        # preferences
         self.browser_preference = blueprint.preference
         self.pref_show_system_objects = blueprint.preference.preference(
             'display', 'show_system_objects'
         )
         self.pref_show_node = self.browser_preference.preference(
             'node', 'show_node_' + self.node_type,
-            self.label, 'boolean', self.SHOW_ON_BROWSER, category_label=gettext('Nodes')
+            self.label, 'boolean', self.SHOW_ON_BROWSER,
+            category_label=gettext('Nodes')
         )
 
 
@@ -474,18 +483,18 @@ class BrowserPluginModule(PgAdminModule):
 @login_required
 def index():
     """Render and process the main browser window."""
-    # Get the Gravatar
-    Gravatar(
-        current_app,
-        size=100,
-        rating='g',
-        default='retro',
-        force_default=False,
-        use_ssl=True,
-        base_url=None
-    )
+    # Register Gravatar module with the app only if required
+    if config.SHOW_GRAVATAR_IMAGE:
+        Gravatar(
+            current_app,
+            size=100,
+            rating='g',
+            default='retro',
+            force_default=False,
+            use_ssl=True,
+            base_url=None
+        )
 
-    msg = None
     # Get the current version info from the website, and flash a message if
     # the user is out of date, and the check is enabled.
     if config.UPGRADE_CHECK_ENABLED:
@@ -497,7 +506,10 @@ def index():
             # Do not wait for more than 5 seconds.
             # It stuck on rendering the browser.html, while working in the
             # broken network.
-            response = urlreq.urlopen(url, data, 5)
+            if os.path.exists(config.CA_FILE):
+                response = urlreq.urlopen(url, data, 5, cafile=config.CA_FILE)
+            else:
+                response = urlreq.urlopen(url, data, 5)
             current_app.logger.debug(
                 'Version check HTTP response code: %d' % response.getcode()
             )
@@ -505,7 +517,7 @@ def index():
             if response.getcode() == 200:
                 data = json.loads(response.read().decode('utf-8'))
                 current_app.logger.debug('Response data: %s' % data)
-        except:
+        except Exception:
             current_app.logger.exception('Exception when checking for update')
 
         if data is not None:
@@ -537,7 +549,14 @@ def index():
     if user_languages:
         language = user_languages.get() or 'en'
 
-    response.set_cookie("PGADMIN_LANGUAGE", language)
+    domain = dict()
+    if config.COOKIE_DEFAULT_DOMAIN and\
+            config.COOKIE_DEFAULT_DOMAIN != 'localhost':
+        domain['domain'] = config.COOKIE_DEFAULT_DOMAIN
+
+    response.set_cookie("PGADMIN_LANGUAGE", value=language,
+                        path=config.COOKIE_DEFAULT_PATH,
+                        **domain)
 
     return response
 
@@ -583,7 +602,7 @@ def utils():
         from pgadmin.utils.driver import get_driver
         driver = get_driver(PG_DEFAULT_DRIVER)
         pg_libpq_version = driver.libpq_version()
-    except:
+    except Exception as e:
         pg_libpq_version = 0
 
     for submodule in current_blueprint.submodules:
@@ -602,7 +621,8 @@ def utils():
             editor_insert_pair_brackets=insert_pair_brackets,
             editor_indent_with_tabs=editor_indent_with_tabs,
             app_name=config.APP_NAME,
-            pg_libpq_version=pg_libpq_version
+            pg_libpq_version=pg_libpq_version,
+            support_ssh_tunnel=config.SUPPORT_SSH_TUNNEL
         ),
         200, {'Content-Type': 'application/x-javascript'})
 
@@ -664,15 +684,6 @@ def browser_css():
     """Render and return CSS snippets from the nodes and modules."""
     snippets = []
 
-    # Get configurable options
-    prefs = Preferences.module('sqleditor')
-
-    sql_font_size_pref = prefs.preference('sql_font_size')
-    sql_font_size = round(float(sql_font_size_pref.get()), 2)
-
-    if sql_font_size != 0:
-        snippets.append('.CodeMirror { font-size: %sem; }' % str(sql_font_size))
-
     for submodule in blueprint.submodules:
         snippets.extend(submodule.csssnippets)
     return make_response(
@@ -692,9 +703,12 @@ def get_nodes():
 
     return make_json_response(data=nodes)
 
+
 # Only register route if SECURITY_CHANGEABLE is set to True
 # We can't access app context here so cannot
 # use app.config['SECURITY_CHANGEABLE']
+
+
 if hasattr(config, 'SECURITY_CHANGEABLE') and config.SECURITY_CHANGEABLE:
     @blueprint.route("/change_password", endpoint="change_password",
                      methods=['GET', 'POST'])
@@ -716,7 +730,10 @@ if hasattr(config, 'SECURITY_CHANGEABLE') and config.SECURITY_CHANGEABLE:
             except SOCKETErrorException as e:
                 # Handle socket errors which are not covered by SMTPExceptions.
                 logging.exception(str(e), exc_info=True)
-                flash(gettext(u'SMTP Socket error: {}\nYour password has not been changed.').format(e), 'danger')
+                flash(gettext(u'SMTP Socket error: {}\n'
+                              u'Your password has not been changed.'
+                              ).format(e),
+                      'danger')
                 has_error = True
             except (SMTPConnectError, SMTPResponseException,
                     SMTPServerDisconnected, SMTPDataError, SMTPHeloError,
@@ -724,12 +741,21 @@ if hasattr(config, 'SECURITY_CHANGEABLE') and config.SECURITY_CHANGEABLE:
                     SMTPRecipientsRefused) as e:
                 # Handle smtp specific exceptions.
                 logging.exception(str(e), exc_info=True)
-                flash(gettext(u'SMTP error: {}\nYour password has not been changed.').format(e), 'danger')
+                flash(gettext(u'SMTP error: {}\n'
+                              u'Your password has not been changed.'
+                              ).format(e),
+                      'danger')
                 has_error = True
             except Exception as e:
                 # Handle other exceptions.
                 logging.exception(str(e), exc_info=True)
-                flash(gettext(u'Error: {}\nYour password has not been changed.').format(e), 'danger')
+                flash(
+                    gettext(
+                        u'Error: {}\n'
+                        u'Your password has not been changed.'
+                    ).format(e),
+                    'danger'
+                )
                 has_error = True
 
             if request.json is None and not has_error:
@@ -747,7 +773,6 @@ if hasattr(config, 'SECURITY_CHANGEABLE') and config.SECURITY_CHANGEABLE:
             change_password_form=form,
             **_ctx('change_password'))
 
-
 # Only register route if SECURITY_RECOVERABLE is set to True
 if hasattr(config, 'SECURITY_RECOVERABLE') and config.SECURITY_RECOVERABLE:
 
@@ -768,7 +793,6 @@ if hasattr(config, 'SECURITY_RECOVERABLE') and config.SECURITY_RECOVERABLE:
             current_app._get_current_object(),
             user=user, token=token)
 
-
     @blueprint.route("/reset_password", endpoint="forgot_password",
                      methods=['GET', 'POST'])
     @anonymous_user_required
@@ -788,7 +812,10 @@ if hasattr(config, 'SECURITY_RECOVERABLE') and config.SECURITY_RECOVERABLE:
             except SOCKETErrorException as e:
                 # Handle socket errors which are not covered by SMTPExceptions.
                 logging.exception(str(e), exc_info=True)
-                flash(gettext(u'SMTP Socket error: {}\nYour password has not been changed.').format(e), 'danger')
+                flash(gettext(u'SMTP Socket error: {}\n'
+                              u'Your password has not been changed.'
+                              ).format(e),
+                      'danger')
                 has_error = True
             except (SMTPConnectError, SMTPResponseException,
                     SMTPServerDisconnected, SMTPDataError, SMTPHeloError,
@@ -797,12 +824,18 @@ if hasattr(config, 'SECURITY_RECOVERABLE') and config.SECURITY_RECOVERABLE:
 
                 # Handle smtp specific exceptions.
                 logging.exception(str(e), exc_info=True)
-                flash(gettext(u'SMTP error: {}\nYour password has not been changed.').format(e), 'danger')
+                flash(gettext(u'SMTP error: {}\n'
+                              u'Your password has not been changed.'
+                              ).format(e),
+                      'danger')
                 has_error = True
             except Exception as e:
                 # Handle other exceptions.
                 logging.exception(str(e), exc_info=True)
-                flash(gettext(u'Error: {}\nYour password has not been changed.').format(e), 'danger')
+                flash(gettext(u'Error: {}\n'
+                              u'Your password has not been changed.'
+                              ).format(e),
+                      'danger')
                 has_error = True
 
             if request.json is None and not has_error:
@@ -817,14 +850,17 @@ if hasattr(config, 'SECURITY_RECOVERABLE') and config.SECURITY_RECOVERABLE:
             forgot_password_form=form,
             **_ctx('forgot_password'))
 
-
-    # We are not in app context so cannot use url_for('browser.forgot_password')
+    # We are not in app context so cannot use
+    # url_for('browser.forgot_password')
     # So hard code the url '/browser/reset_password' while passing as
     # parameter to slash_url_suffix function.
-    @blueprint.route('/reset_password' + slash_url_suffix(
-        '/browser/reset_password', '<token>'),
-                     methods=['GET', 'POST'],
-                     endpoint='reset_password')
+    @blueprint.route(
+        '/reset_password' + slash_url_suffix(
+            '/browser/reset_password', '<token>'
+        ),
+        methods=['GET', 'POST'],
+        endpoint='reset_password'
+    )
     @anonymous_user_required
     def reset_password(token):
         """View function that handles a reset password request."""
@@ -847,7 +883,10 @@ if hasattr(config, 'SECURITY_RECOVERABLE') and config.SECURITY_RECOVERABLE:
             except SOCKETErrorException as e:
                 # Handle socket errors which are not covered by SMTPExceptions.
                 logging.exception(str(e), exc_info=True)
-                flash(gettext(u'SMTP Socket error: {}\nYour password has not been changed.').format(e), 'danger')
+                flash(gettext(u'SMTP Socket error: {}\n'
+                              u'Your password has not been changed.'
+                              ).format(e),
+                      'danger')
                 has_error = True
             except (SMTPConnectError, SMTPResponseException,
                     SMTPServerDisconnected, SMTPDataError, SMTPHeloError,
@@ -856,12 +895,18 @@ if hasattr(config, 'SECURITY_RECOVERABLE') and config.SECURITY_RECOVERABLE:
 
                 # Handle smtp specific exceptions.
                 logging.exception(str(e), exc_info=True)
-                flash(gettext(u'SMTP error: {}\nYour password has not been changed.').format(e), 'danger')
+                flash(gettext(u'SMTP error: {}\n'
+                              u'Your password has not been changed.'
+                              ).format(e),
+                      'danger')
                 has_error = True
             except Exception as e:
                 # Handle other exceptions.
                 logging.exception(str(e), exc_info=True)
-                flash(gettext(u'Error: {}\nYour password has not been changed.').format(e), 'danger')
+                flash(gettext(u'Error: {}\n'
+                              u'Your password has not been changed.'
+                              ).format(e),
+                      'danger')
                 has_error = True
 
             if not has_error:
