@@ -28,7 +28,8 @@ class FtsTemplateAddTestCase(BaseTestGenerator):
     scenarios = [
         # Fetching default URL for FTS template node.
         (
-        'Fetch FTS templates Node URL', dict(url='/browser/fts_template/obj/'))
+            'Fetch FTS templates Node URL',
+            dict(url='/browser/fts_template/obj/'))
     ]
 
     def runTest(self):
