@@ -2,26 +2,24 @@
 define('pgadmin.node.procedure', [
   'sources/gettext', 'sources/url_for', 'jquery', 'underscore',
   'underscore.string', 'sources/pgadmin', 'pgadmin.browser', 'alertify',
-  'pgadmin.node.function', 'pgadmin.browser.collection',
-  'pgadmin.browser.server.privilege'
-], function(gettext, url_for, $, _, S, pgAdmin, pgBrowser, alertify, Function) {
+  'pgadmin.node.function', 'pgadmin.node.schema.dir/child',
+  'pgadmin.browser.collection', 'pgadmin.browser.server.privilege',
+], function(gettext, url_for, $, _, S, pgAdmin, pgBrowser, alertify, Function, schemaChild) {
 
   if (!pgBrowser.Nodes['coll-procedure']) {
-    var procedures = pgAdmin.Browser.Nodes['coll-procedure'] =
+    pgAdmin.Browser.Nodes['coll-procedure'] =
       pgAdmin.Browser.Collection.extend({
         node: 'procedure',
         label: gettext('Procedures'),
         type: 'coll-procedure',
         columns: ['name', 'funcowner', 'description'],
-        hasStatistics: true
+        hasStatistics: true,
       });
-  };
-
-  var pgSchemaNode = pgBrowser.Nodes['schema'];
+  }
 
   // Inherit Functions Node
   if (!pgBrowser.Nodes['procedure']) {
-    pgAdmin.Browser.Nodes['procedure'] = pgBrowser.Node.extend({
+    pgAdmin.Browser.Nodes['procedure'] = schemaChild.SchemaChildNode.extend({
       type: 'procedure',
       sqlAlterHelp: 'sql-alterprocedure.html',
       sqlCreateHelp: 'sql-createprocedure.html',
@@ -32,11 +30,10 @@ define('pgadmin.node.procedure', [
       hasDepends: true,
       hasStatistics: true,
       hasScriptTypes: ['create', 'exec'],
-      parent_type: ['schema', 'catalog'],
       Init: function() {
         /* Avoid mulitple registration of menus */
         if (this.proc_initialized)
-            return;
+          return;
 
         this.proc_initialized = true;
 
@@ -46,54 +43,55 @@ define('pgadmin.node.procedure', [
           applies: ['object', 'context'], callback: 'show_obj_properties',
           category: 'create', priority: 4, label: gettext('Procedure...'),
           icon: 'wcTabIcon icon-procedure', data: {action: 'create', check:
-          false}, enable: 'canCreateProc'
+          false}, enable: 'canCreateProc',
         },{
           name: 'create_procedure', node: 'procedure', module: this,
           applies: ['object', 'context'], callback: 'show_obj_properties',
           category: 'create', priority: 4, label: gettext('Procedure...'),
           icon: 'wcTabIcon icon-procedure', data: {action: 'create', check:
-          true}, enable: 'canCreateProc'
+          true}, enable: 'canCreateProc',
         },{
           name: 'create_procedure', node: 'schema', module: this,
           applies: ['object', 'context'], callback: 'show_obj_properties',
           category: 'create', priority: 4, label: gettext('Procedure...'),
           icon: 'wcTabIcon icon-procedure', data: {action: 'create', check:
-          true}, enable: 'canCreateProc'
-        }
+          true}, enable: 'canCreateProc',
+        },
         ]);
       },
-      canDrop: pgSchemaNode.canChildDrop,
-      canDropCascade: false,
-      canCreateProc: function(itemData, item, data) {
+      canCreateProc: function(itemData, item) {
         var node_hierarchy = this.getTreeNodeHierarchy.apply(this, [item]);
 
         // Do not provide Create option in catalog
         if ('catalog' in node_hierarchy)
           return false;
 
-        // Procedures supported only in PPAS
-        if ('server' in node_hierarchy && node_hierarchy['server'].server_type == "ppas")
-          return true;
-
-        return false;
+        // Procedures supported only in PPAS and PG >= 11
+        return (
+          'server' in node_hierarchy && (
+          node_hierarchy['server'].server_type == 'ppas' ||
+            (node_hierarchy['server'].server_type == 'pg' &&
+             node_hierarchy['server'].version >= 110000)
+          )
+        );
       },
       model: Function.model.extend({
         defaults: _.extend({},
           Function.model.prototype.defaults,
           {
-            lanname: 'edbspl'
+            lanname: 'edbspl',
           }
         ),
-        canVarAdd: function(m){
+        canVarAdd: function() {
           var server = this.node_info.server;
-            if (server.version < 90500) {
-              return false;
-           }
-           else {
-             return true;
-           }
+          if (server.version < 90500) {
+            return false;
+          }
+          else {
+            return true;
+          }
         },
-        isVisible: function(m){
+        isVisible: function() {
           if (this.name == 'sysfunc') { return false; }
           else if (this.name == 'sysproc') { return true; }
           return false;
@@ -102,46 +100,59 @@ define('pgadmin.node.procedure', [
           if(this.node_info &&  'catalog' in this.node_info) {
             return true;
           }
-          name = this.name;
-          switch(name){
-            case 'provolatility':
-            case 'proisstrict':
-            case 'prosecdef':
-            case 'procost':
-            case 'proleakproof':
-            case 'variables':
-               var server = this.node_info.server;
-               if (server.version < 90500) {
-                 return true;
-               }
-               else {
-                 return false;
-               }
-               break;
-            case 'prorows':
-              var server = this.node_info.server;
-              if(server.version >= 90500 && m.get('proretset') == true) {
-                return false;
-              }
-              else {
-                return true;
-              }
-              break;
-            case 'funcowner':
-            case 'lanname':
-            case 'proargs':
+          switch(this.name){
+          case 'provolatile':
+          case 'proisstrict':
+          case 'procost':
+          case 'proleakproof':
+            if(this.node_info.server.version < 90500 ||
+              this.node_info.server.server_type != 'ppas' ||
+              m.get('lanname') != 'edbspl') {
+
+              setTimeout(function() {
+                m.set('provolatile', undefined);
+                m.set('proisstrict', undefined);
+                m.set('procost', undefined);
+                m.set('proleakproof', undefined);
+              }, 10);
               return true;
-            default:
+            }
+            else{
               return false;
-              break;
+            }
+
+          case 'variables':
+          case 'prosecdef':
+            return this.node_info.server.version < 90500;
+          case 'prorows':
+            var server = this.node_info.server;
+            return !(server.version >= 90500 && m.get('proretset') == true);
+          case 'funcowner':
+          case 'proargs':
+            return true;
+          case 'proparallel':
+            if (this.node_info.server.version < 90600 ||
+              this.node_info.server.server_type != 'ppas' ||
+              m.get('lanname') != 'edbspl') {
+              setTimeout(function() {
+                m.set('proparallel', undefined);
+              }, 10);
+              return true;
+            }
+            else{
+              return false;
+            }
+          case 'lanname':
+            return this.node_info.server.version < 110000;
+          default:
+            return false;
           }
-          return false;
-       },
-       validate: function()
+        },
+        validate: function()
         {
           var err = {},
-              errmsg,
-              seclabels = this.get('seclabels');
+            errmsg,
+            seclabels = this.get('seclabels');
 
           if (_.isUndefined(this.get('name')) || String(this.get('name')).replace(/^\s+|\s+$/g, '') == '') {
             err['name'] = gettext('Name cannot be empty.');
@@ -158,11 +169,24 @@ define('pgadmin.node.procedure', [
             errmsg = errmsg || err['lanname'];
           }
 
-          if (_.isUndefined(this.get('prosrc')) || String(this.get('prosrc')).replace(/^\s+|\s+$/g, '') == '') {
-            err['prosrc'] = gettext('Code cannot be empty.');
-            errmsg = errmsg || err['prosrc'];
-          }
+          if (String(this.get('lanname')) == 'c') {
+            if (_.isUndefined(this.get('probin')) || String(this.get('probin'))
+              .replace(/^\s+|\s+$/g, '') == '') {
+              err['probin'] = gettext('Object File cannot be empty.');
+              errmsg = errmsg || err['probin'];
+            }
 
+            if (_.isUndefined(this.get('prosrc_c')) || String(this.get('prosrc_c')).replace(/^\s+|\s+$/g, '') == '') {
+              err['prosrc_c'] = gettext('Link Symbol cannot be empty.');
+              errmsg = errmsg || err['prosrc_c'];
+            }
+          }
+          else {
+            if (_.isUndefined(this.get('prosrc')) || String(this.get('prosrc')).replace(/^\s+|\s+$/g, '') == '') {
+              err['prosrc'] = gettext('Code cannot be empty.');
+              errmsg = errmsg || err['prosrc'];
+            }
+          }
 
           if (seclabels) {
             var secLabelsErr;
@@ -179,8 +203,8 @@ define('pgadmin.node.procedure', [
 
           return null;
         },
-      })
-  });
+      }),
+    });
 
   }
 
