@@ -2,7 +2,7 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2017, The pgAdmin Development Team
+# Copyright (C) 2013 - 2018, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
@@ -14,7 +14,7 @@ from functools import wraps
 
 import pgadmin.browser.server_groups.servers.databases.schemas as schemas
 from flask import render_template, make_response, request, jsonify
-from flask_babel import gettext
+from flask_babelex import gettext
 from pgadmin.browser.collection import CollectionNodeModule
 from pgadmin.browser.server_groups.servers.databases.schemas.utils import \
     parse_rule_definition
@@ -248,10 +248,10 @@ class RuleView(PGChildNodeView):
             return gone(gettext("""Could not find the rule in the table."""))
 
         res = self.blueprint.generate_browser_node(
-                rset['rows'][0]['oid'],
-                tid,
-                rset['rows'][0]['name'],
-                icon="icon-rule"
+            rset['rows'][0]['oid'],
+            tid,
+            rset['rows'][0]['name'],
+            icon="icon-rule"
         )
 
         return make_json_response(
@@ -485,7 +485,9 @@ class RuleView(PGChildNodeView):
             if not status:
                 return internal_server_error(errormsg=res)
             if len(res['rows']) == 0:
-                return gone(gettext("""Could not find the rule in the table."""))
+                return gone(
+                    gettext("""Could not find the rule in the table.""")
+                )
             res_data = parse_rule_definition(res)
 
             old_data = res_data
