@@ -2,19 +2,21 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2017, The pgAdmin Development Team
+# Copyright (C) 2013 - 2018, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
 
-import os, sys
+import os
+import sys
 
 from flask import render_template
-from flask_babel import gettext as _
+from flask_babelex import gettext as _
 from pgadmin.utils.preferences import Preferences
 
 import config
 
+
 class ServerType(object):
     """
     Server Type
