@@ -1,9 +1,13 @@
 define('pgadmin.browser.node', [
+  'sources/tree/pgadmin_tree_node',
   'sources/gettext', 'jquery', 'underscore', 'underscore.string', 'sources/pgadmin',
   'pgadmin.browser.menu', 'backbone', 'pgadmin.alertifyjs', 'pgadmin.browser.datamodel',
   'backform', 'sources/browser/generate_url', 'sources/utils', 'pgadmin.browser.utils',
   'pgadmin.backform',
-], function(gettext, $, _, S, pgAdmin, Menu, Backbone, Alertify, pgBrowser, Backform, generateUrl, commonUtils) {
+], function(
+  pgadminTreeNode,
+  gettext, $, _, S, pgAdmin, Menu, Backbone, Alertify, pgBrowser, Backform, generateUrl, commonUtils
+) {
 
   var wcDocker = window.wcDocker,
     keyCode = {
@@ -28,7 +32,7 @@ define('pgadmin.browser.node', [
   //
   // It is unlikely - we will instantiate an object for this class.
   // (Inspired by Backbone.extend function)
-  pgBrowser.Node.extend = function(props) {
+  pgBrowser.Node.extend = function(props, initialize) {
     var parent = this;
     var child;
 
@@ -44,6 +48,10 @@ define('pgadmin.browser.node', [
     // Make sure - a child have all the callbacks of the parent.
     child.callbacks = _.extend({}, parent.callbacks, props.callbacks);
 
+    // Let's not bind the callbacks, or initialize the child.
+    if (initialize === false)
+      return child;
+
     var bindToChild = function(cb) {
         if (typeof(child.callbacks[cb]) == 'function') {
           child.callbacks[cb] = child.callbacks[cb].bind(child);
@@ -721,30 +729,30 @@ define('pgadmin.browser.node', [
             $.ajax({
               url: obj.generate_url(i, input.url, d, true),
               type: 'DELETE',
-              success: function(res) {
-                if (res.success == 0) {
-                  pgBrowser.report_error(res.errormsg, res.info);
-                } else {
-                  pgBrowser.removeTreeNode(i, true);
+            })
+            .done(function(res) {
+              if (res.success == 0) {
+                pgBrowser.report_error(res.errormsg, res.info);
+              } else {
+                pgBrowser.removeTreeNode(i, true);
+              }
+              return true;
+            })
+            .fail(function(jqx) {
+              var msg = jqx.responseText;
+              /* Error from the server */
+              if (jqx.status == 417 || jqx.status == 410 || jqx.status == 500) {
+                try {
+                  var data = JSON.parse(jqx.responseText);
+                  msg = data.errormsg;
+                } catch (e) {
+                  console.warn(e.stack || e);
                 }
-                return true;
-              },
-              error: function(jqx) {
-                var msg = jqx.responseText;
-                /* Error from the server */
-                if (jqx.status == 417 || jqx.status == 410 || jqx.status == 500) {
-                  try {
-                    var data = $.parseJSON(jqx.responseText);
-                    msg = data.errormsg;
-                  } catch (e) {
-                    console.warn(e.stack || e);
-                  }
-                }
-                pgBrowser.report_error(
-                  S(gettext('Error dropping %s: "%s"'))
-                  .sprintf(obj.label, objName)
-                  .value(), msg);
-              },
+              }
+              pgBrowser.report_error(
+                S(gettext('Error dropping %s: "%s"'))
+                .sprintf(obj.label, objName)
+                .value(), msg);
             });
           },
           null).show();
@@ -1140,7 +1148,7 @@ define('pgadmin.browser.node', [
               icon: 'fa fa-lg fa-pencil-square-o',
               disabled: !that.canEdit,
               register: function(btn) {
-                btn.click(function() {
+                btn.on('click',() => {
                   onEdit();
                 });
               },
@@ -1154,7 +1162,7 @@ define('pgadmin.browser.node', [
               icon: 'fa fa-lg fa-info',
               disabled: (that.sqlAlterHelp == '' && that.sqlCreateHelp == '') ? true : false,
               register: function(btn) {
-                btn.click(function() {
+                btn.on('click',() => {
                   onSqlHelp();
                 });
               },
@@ -1359,7 +1367,7 @@ define('pgadmin.browser.node', [
               icon: 'fa fa-lg fa-info',
               disabled: (that.sqlAlterHelp == '' && that.sqlCreateHelp == '') ? true : false,
               register: function(btn) {
-                btn.click(function() {
+                btn.on('click',() => {
                   onSqlHelp();
                 });
               },
@@ -1371,7 +1379,7 @@ define('pgadmin.browser.node', [
               icon: 'fa fa-lg fa-question',
               disabled: (that.dialogHelp == '') ? true : false,
               register: function(btn) {
-                btn.click(function() {
+                btn.on('click',() => {
                   onDialogHelp();
                 });
               },
@@ -1384,7 +1392,7 @@ define('pgadmin.browser.node', [
               disabled: true,
               register: function(btn) {
                 // Save the changes
-                btn.click(function() {
+                btn.on('click',() => {
                   onSave.call(this, view, btn);
                 });
               },
@@ -1396,7 +1404,7 @@ define('pgadmin.browser.node', [
               icon: 'fa fa-lg fa-close',
               disabled: false,
               register: function(btn) {
-                btn.click(function() {
+                btn.on('click',() => {
                   // Removing the action-mode
                   panel.$container.removeAttr('action-mode');
                   onCancelFunc.call(arguments);
@@ -1410,7 +1418,7 @@ define('pgadmin.browser.node', [
               icon: 'fa fa-lg fa-recycle',
               disabled: true,
               register: function(btn) {
-                btn.click(function() {
+                btn.on('click',() => {
                   setTimeout(function() {
                     editFunc.call();
                   }, 0);
@@ -1566,7 +1574,6 @@ define('pgadmin.browser.node', [
      * depends, statistics
      */
     generate_url: function(item, type, d, with_id, info) {
-
       var opURL = {
           'create': 'obj',
           'drop': 'obj',
@@ -1608,24 +1615,7 @@ define('pgadmin.browser.node', [
     Collection: pgBrowser.DataCollection,
     // Base class for Node Data Model
     Model: pgBrowser.DataModel,
-    getTreeNodeHierarchy: function(i) {
-      var idx = 0,
-        res = {},
-        t = pgBrowser.tree,
-        d;
-      do {
-        d = t.itemData(i);
-        if (d._type in pgBrowser.Nodes && pgBrowser.Nodes[d._type].hasId) {
-          res[d._type] = _.extend({}, d, {
-            'priority': idx,
-          });
-          idx -= 1;
-        }
-        i = t.hasParent(i) ? t.parent(i) : null;
-      } while (i);
-
-      return res;
-    },
+    getTreeNodeHierarchy: pgadminTreeNode.getTreeNodeHierarchyFromIdentifier.bind(pgBrowser),
     cache: function(url, node_info, level, data) {
       var cached = this.cached = this.cached || {},
         hash = url,
