@@ -2,7 +2,7 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2017, The pgAdmin Development Team
+# Copyright (C) 2013 - 2018, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
@@ -17,12 +17,12 @@ from selenium.webdriver.common.by import By
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.support.ui import WebDriverWait
 
-
 CURRENT_PATH = os.path.dirname(os.path.realpath(__file__))
 
 try:
     with open(CURRENT_PATH + '/test_data.json') as data_file:
-        config_data = json.load(data_file)['table_insert_update_cases']['add_update']
+        config_data = json.load(data_file)[
+            'table_insert_update_cases']['add_update']
 except Exception as e:
     print(str(e))
 
@@ -44,8 +44,8 @@ class CheckForViewDataTest(BaseFeatureTest):
     """
 
     scenarios = [
-        ("Validate Insert, Update operations in View/Edit data with given test "
-         "data",
+        ("Validate Insert, Update operations in View/Edit data with "
+         "given test data",
          dict())
     ]
 
@@ -53,20 +53,22 @@ class CheckForViewDataTest(BaseFeatureTest):
 
     # query for creating 'defaults_text' table
     defaults_query = """
-CREATE TABLE public.defaults
+CREATE TABLE public.defaults_{0}
 (
-    id serial NOT NULL,
+    {1} serial NOT NULL,
     number_defaults numeric(100) DEFAULT 1,
     number_null numeric(100),
-    text_defaults text COLLATE pg_catalog."default" DEFAULT 'Hello World'::text,
+    text_defaults text COLLATE pg_catalog."default"
+        DEFAULT 'Hello World'::text,
     text_null1 text COLLATE pg_catalog."default",
     text_null2 text COLLATE pg_catalog."default",
     text_null3 text COLLATE pg_catalog."default",
     text_null4 text COLLATE pg_catalog."default",
     json_defaults json DEFAULT '[51, 52]'::json,
     json_null json,
-    boolean_defaults boolean DEFAULT true,
+    boolean_true boolean DEFAULT true,
     boolean_null boolean,
+    boolean_false boolean,
     text_arr text[],
     text_arr_empty text[],
     text_arr_null text[],
@@ -74,29 +76,35 @@ CREATE TABLE public.defaults
     int_arr_empty integer[],
     boolean_arr boolean[],
     boolean_arr_null boolean[],
-    CONSTRAINT defaults_pkey PRIMARY KEY (id)
+    CONSTRAINT defaults_pkey_{0} PRIMARY KEY ({1})
 )
 """
 
     def before(self):
         with test_utils.Database(self.server) as (connection, _):
             if connection.server_version < 90100:
-                self.skipTest("COLLATE is not present in PG versions below v9.1")
+                self.skipTest(
+                    "COLLATE is not present in PG versions below v9.1"
+                )
 
-        connection = test_utils.get_db_connection(self.server['db'],
-                                                  self.server['username'],
-                                                  self.server['db_password'],
-                                                  self.server['host'],
-                                                  self.server['port'],
-                                                  self.server['sslmode'])
+        connection = test_utils.get_db_connection(
+            self.server['db'],
+            self.server['username'],
+            self.server['db_password'],
+            self.server['host'],
+            self.server['port'],
+            self.server['sslmode']
+        )
         test_utils.drop_database(connection, "acceptance_test_db")
         test_utils.create_database(self.server, "acceptance_test_db")
 
         # Create pre-requisite table
-        test_utils.create_table_with_query(
-            self.server,
-            "acceptance_test_db",
-            CheckForViewDataTest.defaults_query)
+        for k, v in {1: 'id', 2: '"ID"'}.items():
+            test_utils.create_table_with_query(
+                self.server,
+                "acceptance_test_db",
+                CheckForViewDataTest.defaults_query.format(k, v))
+
         # Initialize an instance of WebDriverWait with timeout of 3 seconds
         self.wait = WebDriverWait(self.driver, 3)
 
@@ -104,27 +112,31 @@ CREATE TABLE public.defaults
         self.page.wait_for_spinner_to_disappear()
         self.page.add_server(self.server)
         self._tables_node_expandable()
-        self.page.select_tree_item('defaults')
-        # Open Object -> View/Edit data
-        self._view_data_grid()
+        # iterate on both tables
+        for cnt in (1, 2):
+            self.page.select_tree_item('defaults_{0}'.format(str(cnt)))
+            # Open Object -> View/Edit data
+            self._view_data_grid()
 
-        self.page.wait_for_query_tool_loading_indicator_to_disappear()
-        # Run test to insert a new row in table with default values
-        self._add_row()
-        self._verify_row_data(True)
+            self.page.wait_for_query_tool_loading_indicator_to_disappear()
+            # Run test to insert a new row in table with default values
+            self._add_row()
+            self._verify_row_data(True)
 
-        # Run test to copy/paste a row
-        self._copy_paste_row()
-        self.page.close_data_grid()
+            # Run test to copy/paste a row
+            self._copy_paste_row()
+            self.page.close_data_grid()
 
     def after(self):
         self.page.remove_server(self.server)
-        connection = test_utils.get_db_connection(self.server['db'],
-                                                  self.server['username'],
-                                                  self.server['db_password'],
-                                                  self.server['host'],
-                                                  self.server['port'],
-                                                  self.server['sslmode'])
+        connection = test_utils.get_db_connection(
+            self.server['db'],
+            self.server['username'],
+            self.server['db_password'],
+            self.server['host'],
+            self.server['port'],
+            self.server['sslmode']
+        )
         test_utils.drop_database(connection, "acceptance_test_db")
 
     @staticmethod
@@ -137,7 +149,7 @@ CREATE TABLE public.defaults
             xpath_grid_row = "//*[contains(@class, 'ui-widget-content') " \
                              "and contains(@style, 'top:25px')]"
 
-        xpath_row_cell = '//div[contains(@class, "'+cell+'")]'
+        xpath_row_cell = '//div[contains(@class, "' + cell + '")]'
 
         xpath_cell = '{0}{1}'.format(xpath_grid_row, xpath_row_cell)
 
@@ -148,7 +160,7 @@ CREATE TABLE public.defaults
         wait = WebDriverWait(self.driver, 5)
         try:
             wait.until(EC.text_to_be_present_in_element(
-                (By.XPATH, xpath+"//span"), str(value)),
+                (By.XPATH, xpath + "//span"), str(value)),
                 CheckForViewDataTest.TIMEOUT_STRING
             )
         except Exception:
@@ -173,6 +185,8 @@ CREATE TABLE public.defaults
             (By.XPATH, xpath)), CheckForViewDataTest.TIMEOUT_STRING
         )
         cell_el = self.page.find_by_xpath(xpath)
+        self.page.driver.execute_script("arguments[0].scrollIntoView()",
+                                        cell_el)
         ActionChains(self.driver).move_to_element(cell_el).double_click(
             cell_el
         ).perform()
@@ -191,15 +205,24 @@ CREATE TABLE public.defaults
             ActionChains(self.driver).send_keys(value).perform()
 
             # Click on editor's Save button
-            self.page.find_by_xpath("//*[contains(@class, 'pg_text_editor')]"
-                                    "//button[contains(@class, 'fa-save')]").click()
+            self.page.find_by_xpath(
+                "//*[contains(@class, 'pg_text_editor')]"
+                "//button[contains(@class, 'fa-save')]"
+            ).click()
         else:
+            # Boolean editor test for to True click
             if data[1] == 'true':
-                checkbox_el = cell_el.find_element_by_xpath(".//input")
+                checkbox_el = cell_el.find_element_by_xpath(
+                    ".//*[contains(@class, 'multi-checkbox')]")
                 checkbox_el.click()
-                ActionChains(self.driver).move_to_element(checkbox_el).double_click(
-                    checkbox_el
-                ).perform()
+            # Boolean editor test for to False click
+            elif data[1] == 'false':
+                checkbox_el = cell_el.find_element_by_xpath(
+                    ".//*[contains(@class, 'multi-checkbox')]")
+                # Sets true
+                checkbox_el.click()
+                # Sets false
+                ActionChains(self.driver).click(checkbox_el).perform()
 
     def _tables_node_expandable(self):
         self.page.toggle_open_tree_item(self.server['name'])
@@ -211,12 +234,13 @@ CREATE TABLE public.defaults
 
     def _view_data_grid(self):
         self.page.driver.find_element_by_link_text("Object").click()
-        ActionChains(self.page.driver) \
-            .move_to_element(
-                self.page.driver.find_element_by_link_text("View/Edit Data")) \
-            .perform()
+        ActionChains(
+            self.page.driver
+        ).move_to_element(
+            self.page.driver.find_element_by_link_text("View/Edit Data")
+        ).perform()
         self.page.find_by_partial_link_text("All Rows").click()
-
+        time.sleep(1)
         # wait until datagrid frame is loaded.
         self.page.click_tab('Edit Data -')
 
@@ -268,7 +292,7 @@ CREATE TABLE public.defaults
     def _add_row(self):
         for idx in range(1, len(config_data.keys()) + 1):
             cell_xpath = CheckForViewDataTest._get_cell_xpath(
-                'r'+str(idx), 1
+                'r' + str(idx), 1
             )
             time.sleep(0.2)
             self._update_cell(cell_xpath, config_data[str(idx)])
@@ -293,10 +317,20 @@ CREATE TABLE public.defaults
         result_row = self.page.find_by_xpath(xpath)
 
         # List of row values in an array
-        cells = [el.text for el in result_row.find_elements_by_tag_name('div')]
         for idx in range(1, len(config_data.keys()) + 1):
             # after copy & paste row, the first cell of row 1 and
             # row 2(being primary keys) won't match
             # see if cell values matched to actual value
+            element = result_row.find_element_by_class_name("r" + str(idx))
+            self.page.driver.execute_script("arguments[0].scrollIntoView()",
+                                            element)
+
             if (idx != 1 and not is_new_row) or is_new_row:
-                self.assertEquals(cells[idx], config_data[str(idx)][1])
+                self.assertEquals(element.text, config_data[str(idx)][1])
+
+        # scroll browser back to the left
+        # to reset position so other assertions can succeed
+        for idx in range(len(config_data.keys()), 1, -1):
+            element = result_row.find_element_by_class_name("r" + str(idx))
+            self.page.driver.execute_script("arguments[0].scrollIntoView()",
+                                            element)
