@@ -16,6 +16,7 @@ object.
 import random
 import select
 import sys
+import datetime
 from collections import deque
 import simplejson as json
 import psycopg2
@@ -49,7 +50,6 @@ else:
 
 _ = gettext
 
-
 # Register global type caster which will be applicable to all connections.
 register_global_typecasters()
 
@@ -136,9 +136,20 @@ class Connection(BaseConnection):
         formatted error message if flag is set to true else return
         normal error message.
 
+    * check_notifies(required_polling)
+      - Check for the notify messages by polling the connection or after
+        execute is there in notifies.
+
+    * get_notifies()
+      - This function will returns list of notifies received from database
+        server.
+
+    * pq_encrypt_password_conn()
+      - This function will return the encrypted password for database server
+      - greater than or equal to 10.
     """
 
-    def __init__(self, manager, conn_id, db, auto_reconnect=True, async=0,
+    def __init__(self, manager, conn_id, db, auto_reconnect=True, async_=0,
                  use_binary_placeholder=False, array_to_string=False):
         assert (manager is not None)
         assert (conn_id is not None)
@@ -148,13 +159,14 @@ class Connection(BaseConnection):
         self.db = db if db is not None else manager.db
         self.conn = None
         self.auto_reconnect = auto_reconnect
-        self.async = async
+        self.async_ = async_
         self.__async_cursor = None
         self.__async_query_id = None
         self.__backend_pid = None
         self.execution_aborted = False
         self.row_count = 0
         self.__notices = None
+        self.__notifies = None
         self.password = None
         # This flag indicates the connection status (connected/disconnected).
         self.wasConnected = False
@@ -177,7 +189,7 @@ class Connection(BaseConnection):
         res = dict()
         res['conn_id'] = self.conn_id
         res['database'] = self.db
-        res['async'] = self.async
+        res['async_'] = self.async_
         res['wasConnected'] = self.wasConnected
         res['auto_reconnect'] = self.auto_reconnect
         res['use_binary_placeholder'] = self.use_binary_placeholder
@@ -190,7 +202,7 @@ class Connection(BaseConnection):
             self.conn_id, self.db,
             'Connected' if self.conn and not self.conn.closed else
             "Disconnected",
-            self.async
+            self.async_
         )
 
     def __str__(self):
@@ -198,7 +210,7 @@ class Connection(BaseConnection):
             self.conn_id, self.db,
             'Connected' if self.conn and not self.conn.closed else
             "Disconnected",
-            self.async
+            self.async_
         )
 
     def connect(self, **kwargs):
@@ -211,13 +223,25 @@ class Connection(BaseConnection):
         pg_conn = None
         password = None
         passfile = None
-        mgr = self.manager
+        manager = self.manager
 
         encpass = kwargs['password'] if 'password' in kwargs else None
         passfile = kwargs['passfile'] if 'passfile' in kwargs else None
+        tunnel_password = kwargs['tunnel_password'] if 'tunnel_password' in \
+                                                       kwargs else ''
+
+        # Check SSH Tunnel needs to be created
+        if manager.use_ssh_tunnel == 1 and not manager.tunnel_created:
+            status, error = manager.create_ssh_tunnel(tunnel_password)
+            if not status:
+                return False, error
+
+        # Check SSH Tunnel is alive or not.
+        if manager.use_ssh_tunnel == 1:
+            manager.check_ssh_tunnel_alive()
 
         if encpass is None:
-            encpass = self.password or getattr(mgr, 'password', None)
+            encpass = self.password or getattr(manager, 'password', None)
 
         # Reset the existing connection password
         if self.reconnecting is not False:
@@ -240,6 +264,7 @@ class Connection(BaseConnection):
                     password = password.decode()
 
             except Exception as e:
+                manager.stop_ssh_tunnel()
                 current_app.logger.exception(e)
                 return False, \
                     _(
@@ -251,16 +276,16 @@ class Connection(BaseConnection):
         # we will check for pgpass file availability from connection manager
         # if it's present then we will use it
         if not password and not encpass and not passfile:
-            passfile = mgr.passfile if mgr.passfile else None
+            passfile = manager.passfile if manager.passfile else None
 
         try:
             if hasattr(str, 'decode'):
                 database = self.db.encode('utf-8')
-                user = mgr.user.encode('utf-8')
+                user = manager.user.encode('utf-8')
                 conn_id = self.conn_id.encode('utf-8')
             else:
                 database = self.db
-                user = mgr.user
+                user = manager.user
                 conn_id = self.conn_id
 
             import os
@@ -268,29 +293,34 @@ class Connection(BaseConnection):
                 config.APP_NAME, conn_id)
 
             pg_conn = psycopg2.connect(
-                host=mgr.host,
-                hostaddr=mgr.hostaddr,
-                port=mgr.port,
+                host=manager.local_bind_host if manager.use_ssh_tunnel
+                else manager.host,
+                hostaddr=manager.local_bind_host if manager.use_ssh_tunnel
+                else manager.hostaddr,
+                port=manager.local_bind_port if manager.use_ssh_tunnel
+                else manager.port,
                 database=database,
                 user=user,
                 password=password,
-                async=self.async,
+                async_=self.async_,
                 passfile=get_complete_file_path(passfile),
-                sslmode=mgr.ssl_mode,
-                sslcert=get_complete_file_path(mgr.sslcert),
-                sslkey=get_complete_file_path(mgr.sslkey),
-                sslrootcert=get_complete_file_path(mgr.sslrootcert),
-                sslcrl=get_complete_file_path(mgr.sslcrl),
-                sslcompression=True if mgr.sslcompression else False,
-                service=mgr.service
+                sslmode=manager.ssl_mode,
+                sslcert=get_complete_file_path(manager.sslcert),
+                sslkey=get_complete_file_path(manager.sslkey),
+                sslrootcert=get_complete_file_path(manager.sslrootcert),
+                sslcrl=get_complete_file_path(manager.sslcrl),
+                sslcompression=True if manager.sslcompression else False,
+                service=manager.service,
+                connect_timeout=manager.connect_timeout
             )
 
             # If connection is asynchronous then we will have to wait
             # until the connection is ready to use.
-            if self.async == 1:
+            if self.async_ == 1:
                 self._wait(pg_conn)
 
         except psycopg2.Error as e:
+            manager.stop_ssh_tunnel()
             if e.pgerror:
                 msg = e.pgerror
             elif e.diag.message_detail:
@@ -317,6 +347,7 @@ class Connection(BaseConnection):
         try:
             status, msg = self._initialize(conn_id, **kwargs)
         except Exception as e:
+            manager.stop_ssh_tunnel()
             current_app.logger.exception(e)
             self.conn = None
             if not self.reconnecting:
@@ -324,7 +355,7 @@ class Connection(BaseConnection):
             raise e
 
         if status:
-            mgr._update_password(encpass)
+            manager._update_password(encpass)
         else:
             if not self.reconnecting:
                 self.wasConnected = False
@@ -342,7 +373,7 @@ class Connection(BaseConnection):
 
         status, cur = self.__cursor()
         formatted_exception_msg = self._formatted_exception_msg
-        mgr = self.manager
+        manager = self.manager
 
         def _execute(cur, query, params=None):
             try:
@@ -354,7 +385,7 @@ class Connection(BaseConnection):
 
         # autocommit flag does not work with asynchronous connections.
         # By default asynchronous connection runs in autocommit mode.
-        if self.async == 0:
+        if self.async_ == 0:
             if 'autocommit' in kwargs and kwargs['autocommit'] is False:
                 self.conn.autocommit = False
             else:
@@ -370,10 +401,29 @@ class Connection(BaseConnection):
         if self.use_binary_placeholder:
             register_binary_typecasters(self.conn)
 
-        status = _execute(cur, "SET DateStyle=ISO;"
-                               "SET client_min_messages=notice;"
-                               "SET bytea_output=escape;"
-                               "SET client_encoding='UNICODE';")
+        if self.conn.encoding in ('SQL_ASCII', 'SQLASCII',
+                                  'MULE_INTERNAL', 'MULEINTERNAL'):
+            status = _execute(cur, "SET DateStyle=ISO;"
+                                   "SET client_min_messages=notice;"
+                                   "SET bytea_output=escape;"
+                                   "SET client_encoding='{0}';"
+                              .format(self.conn.encoding))
+            self.python_encoding = 'raw_unicode_escape'
+        else:
+            status = _execute(cur, "SET DateStyle=ISO;"
+                                   "SET client_min_messages=notice;"
+                                   "SET bytea_output=escape;"
+                                   "SET client_encoding='UNICODE';")
+            self.python_encoding = 'utf-8'
+
+        # Replace the python encoding for original name and renamed encodings
+        # psycopg2 removes the underscore in conn.encoding
+        # Setting the encodings dict value will only help for select statements
+        # because for parameterized DML, param values are converted based on
+        # python encoding of pyscopg2s internal encodings dict.
+        for key, val in encodings.items():
+            if key.replace('_', '') == self.conn.encoding:
+                encodings[key] = self.python_encoding
 
         if status is not None:
             self.conn.close()
@@ -381,8 +431,8 @@ class Connection(BaseConnection):
 
             return False, status
 
-        if mgr.role:
-            status = _execute(cur, u"SET ROLE TO %s", [mgr.role])
+        if manager.role:
+            status = _execute(cur, u"SET ROLE TO %s", [manager.role])
 
             if status is not None:
                 self.conn.close()
@@ -401,7 +451,7 @@ class Connection(BaseConnection):
                         "Failed to setup the role with error message:\n{0}"
                     ).format(status)
 
-        if mgr.ver is None:
+        if manager.ver is None:
             status = _execute(cur, "SELECT version()")
 
             if status is not None:
@@ -421,8 +471,8 @@ class Connection(BaseConnection):
 
             if cur.rowcount > 0:
                 row = cur.fetchmany(1)[0]
-                mgr.ver = row['version']
-                mgr.sversion = self.conn.server_version
+                manager.ver = row['version']
+                manager.sversion = self.conn.server_version
 
         status = _execute(cur, """
 SELECT
@@ -434,14 +484,14 @@ FROM
 WHERE db.datname = current_database()""")
 
         if status is None:
-            mgr.db_info = mgr.db_info or dict()
+            manager.db_info = manager.db_info or dict()
             if cur.rowcount > 0:
                 res = cur.fetchmany(1)[0]
-                mgr.db_info[res['did']] = res.copy()
+                manager.db_info[res['did']] = res.copy()
 
                 # We do not have database oid for the maintenance database.
-                if len(mgr.db_info) == 1:
-                    mgr.did = res['did']
+                if len(manager.db_info) == 1:
+                    manager.did = res['did']
 
         status = _execute(cur, """
 SELECT
@@ -453,33 +503,39 @@ WHERE
     rolname = current_user""")
 
         if status is None:
-            mgr.user_info = dict()
+            manager.user_info = dict()
             if cur.rowcount > 0:
-                mgr.user_info = cur.fetchmany(1)[0]
+                manager.user_info = cur.fetchmany(1)[0]
 
         if 'password' in kwargs:
-            mgr.password = kwargs['password']
+            manager.password = kwargs['password']
 
         server_types = None
         if 'server_types' in kwargs and isinstance(
                 kwargs['server_types'], list):
-            server_types = mgr.server_types = kwargs['server_types']
+            server_types = manager.server_types = kwargs['server_types']
 
         if server_types is None:
             from pgadmin.browser.server_groups.servers.types import ServerType
             server_types = ServerType.types()
 
         for st in server_types:
-            if st.instanceOf(mgr.ver):
-                mgr.server_type = st.stype
-                mgr.server_cls = st
+            if st.instanceOf(manager.ver):
+                manager.server_type = st.stype
+                manager.server_cls = st
                 break
 
-        mgr.update_session()
+        manager.update_session()
 
         return True, None
 
     def __cursor(self, server_cursor=False):
+
+        # Check SSH Tunnel is alive or not. If used by the database
+        # server for the connection.
+        if self.manager.use_ssh_tunnel == 1:
+            self.manager.check_ssh_tunnel_alive()
+
         if self.wasConnected is False:
             raise ConnectionLost(
                 self.manager.sid,
@@ -565,11 +621,27 @@ WHERE
 
         return True, cur
 
+    def escape_params_sqlascii(self, params):
+        # The data is unescaped using string_typecasters when selected
+        # We need to esacpe the data so that it does not fail when
+        # it is encoded with python ascii
+        # unicode_escape helps in escaping and unescaping
+        if self.conn:
+            if self.conn.encoding in ('SQL_ASCII', 'SQLASCII',
+                                      'MULE_INTERNAL', 'MULEINTERNAL')\
+               and params is not None and type(params) == dict:
+                    params = dict(
+                        (key, val.encode('unicode_escape')
+                         .decode('raw_unicode_escape'))
+                        for key, val in params.items()
+                    )
+        return params
+
     def __internal_blocking_execute(self, cur, query, params):
         """
         This function executes the query using cursor's execute function,
         but in case of asynchronous connection we need to wait for the
-        transaction to be completed. If self.async is 1 then it is a
+        transaction to be completed. If self.async_ is 1 then it is a
         blocking call.
 
         Args:
@@ -584,8 +656,9 @@ WHERE
         else:
             query = query.encode('utf-8')
 
+        params = self.escape_params_sqlascii(params)
         cur.execute(query, params)
-        if self.async == 1:
+        if self.async_ == 1:
             self._wait(cur.connection)
 
     def execute_on_server_as_csv(self,
@@ -701,7 +774,7 @@ WHERE
 
             header = []
             json_columns = []
-            conn_encoding = cur.connection.encoding
+            conn_encoding = encodings[cur.connection.encoding]
 
             for c in cur.ordered_description():
                 # This is to handle the case in which column name is non-ascii
@@ -847,6 +920,9 @@ WHERE
         else:
             query = query.encode('utf-8')
 
+        # Convert the params based on python_encoding
+        params = self.escape_params_sqlascii(params)
+
         self.__async_cursor = None
         status, cur = self.__cursor()
 
@@ -867,6 +943,7 @@ WHERE
 
         try:
             self.__notices = []
+            self.__notifies = []
             self.execution_aborted = False
             cur.execute(query, params)
             res = self._wait_timeout(cur.connection)
@@ -884,6 +961,9 @@ WHERE
                 )
             )
 
+            # Check for the asynchronous notifies.
+            self.check_notifies()
+
             if self.is_disconnected(pe):
                 raise ConnectionLost(
                     self.manager.sid,
@@ -1166,9 +1246,9 @@ WHERE
             if self.conn.closed:
                 self.conn = None
         pg_conn = None
-        mgr = self.manager
+        manager = self.manager
 
-        password = getattr(mgr, 'password', None)
+        password = getattr(manager, 'password', None)
 
         if password:
             # Fetch Logged in User Details.
@@ -1181,20 +1261,24 @@ WHERE
 
         try:
             pg_conn = psycopg2.connect(
-                host=mgr.host,
-                hostaddr=mgr.hostaddr,
-                port=mgr.port,
+                host=manager.local_bind_host if manager.use_ssh_tunnel
+                else manager.host,
+                hostaddr=manager.local_bind_host if manager.use_ssh_tunnel
+                else manager.hostaddr,
+                port=manager.local_bind_port if manager.use_ssh_tunnel
+                else manager.port,
                 database=self.db,
-                user=mgr.user,
+                user=manager.user,
                 password=password,
-                passfile=get_complete_file_path(mgr.passfile),
-                sslmode=mgr.ssl_mode,
-                sslcert=get_complete_file_path(mgr.sslcert),
-                sslkey=get_complete_file_path(mgr.sslkey),
-                sslrootcert=get_complete_file_path(mgr.sslrootcert),
-                sslcrl=get_complete_file_path(mgr.sslcrl),
-                sslcompression=True if mgr.sslcompression else False,
-                service=mgr.service
+                passfile=get_complete_file_path(manager.passfile),
+                sslmode=manager.ssl_mode,
+                sslcert=get_complete_file_path(manager.sslcert),
+                sslkey=get_complete_file_path(manager.sslkey),
+                sslrootcert=get_complete_file_path(manager.sslrootcert),
+                sslcrl=get_complete_file_path(manager.sslcrl),
+                sslcompression=True if manager.sslcompression else False,
+                service=manager.service,
+                connect_timeout=manager.connect_timeout
             )
 
         except psycopg2.Error as e:
@@ -1339,6 +1423,9 @@ Failed to reset the connection to the server due to following error:
             self.__notices.extend(self.conn.notices)
             self.conn.notices.clear()
 
+        # Check for the asynchronous notifies.
+        self.check_notifies()
+
         # We also need to fetch notices before we return from function in case
         # of any Exception, To avoid code duplication we will return after
         # fetching the notices in case of any Exception
@@ -1456,9 +1543,13 @@ Failed to reset the connection to the server due to following error:
 
             try:
                 pg_conn = psycopg2.connect(
-                    host=self.manager.host,
-                    hostaddr=self.manager.hostaddr,
-                    port=self.manager.port,
+                    host=self.manager.local_bind_host if
+                    self.manager.use_ssh_tunnel else self.manager.host,
+                    hostaddr=self.manager.local_bind_host if
+                    self.manager.use_ssh_tunnel else
+                    self.manager.hostaddr,
+                    port=self.manager.local_bind_port if
+                    self.manager.use_ssh_tunnel else self.manager.port,
                     database=self.db,
                     user=self.manager.user,
                     password=password,
@@ -1472,7 +1563,8 @@ Failed to reset the connection to the server due to following error:
                     sslcrl=get_complete_file_path(self.manager.sslcrl),
                     sslcompression=True if self.manager.sslcompression
                     else False,
-                    service=self.manager.service
+                    service=self.manager.service,
+                    connect_timeout=self.manager.connect_timeout
                 )
 
                 # Get the cursor and run the query
@@ -1511,6 +1603,21 @@ Failed to reset the connection to the server due to following error:
         resp = []
         while self.__notices:
             resp.append(self.__notices.pop(0))
+
+        for notify in self.__notifies:
+            if notify.payload is not None and notify.payload is not '':
+                notify_msg = gettext(
+                    "Asynchronous notification \"{0}\" with payload \"{1}\" "
+                    "received from server process with PID {2}\n"
+                ).format(notify.channel, notify.payload, notify.pid)
+
+            else:
+                notify_msg = gettext(
+                    "Asynchronous notification \"{0}\" received from "
+                    "server process with PID {1}\n"
+                ).format(notify.channel, notify.pid)
+            resp.append(notify_msg)
+
         return resp
 
     def decode_to_utf8(self, value):
@@ -1680,3 +1787,69 @@ Failed to reset the connection to the server due to following error:
 
             return False
         return True
+
+    def check_notifies(self, required_polling=False):
+        """
+        Check for the notify messages by polling the connection or after
+        execute is there in notifies.
+        """
+        if self.conn and required_polling:
+            self.conn.poll()
+
+        if self.conn and hasattr(self.conn, 'notifies') and \
+                len(self.conn.notifies) > 0:
+            self.__notifies.extend(self.conn.notifies)
+            self.conn.notifies = []
+        else:
+            self.__notifies = []
+
+    def get_notifies(self):
+        """
+        This function will returns list of notifies received from database
+        server.
+        """
+        notifies = None
+        # Convert list of Notify objects into list of Dict.
+        if self.__notifies is not None and len(self.__notifies) > 0:
+            notifies = [{'recorded_time': str(datetime.datetime.now()),
+                         'channel': notify.channel,
+                         'payload': notify.payload,
+                         'pid': notify.pid
+                         } for notify in self.__notifies
+                        ]
+        return notifies
+
+    def pq_encrypt_password_conn(self, password, user):
+        """
+        This function will return the encrypted password for database server
+        greater than or equal to 10
+        :param password: password to be encrypted
+        :param user: user of the database server
+        :return:
+        """
+        enc_password = None
+        if psycopg2.__libpq_version__ >= 100000 and \
+                hasattr(psycopg2.extensions, 'encrypt_password'):
+            if self.connected():
+                status, enc_algorithm = \
+                    self.execute_scalar("SHOW password_encryption")
+                if status:
+                    enc_password = psycopg2.extensions.encrypt_password(
+                        password=password, user=user, scope=self.conn,
+                        algorithm=enc_algorithm
+                    )
+        elif psycopg2.__libpq_version__ < 100000:
+            current_app.logger.warning(
+                u"To encrypt passwords the required libpq version is "
+                u"greater than or equal to 100000. Current libpq version "
+                u"is {curr_ver}".format(
+                    curr_ver=psycopg2.__libpq_version__
+                )
+            )
+        elif not hasattr(psycopg2.extensions, 'encrypt_password'):
+            current_app.logger.warning(
+                u"The psycopg2.extensions module does not have the"
+                u"'encrypt_password' method."
+            )
+
+        return enc_password
