@@ -2,7 +2,7 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2017, The pgAdmin Development Team
+# Copyright (C) 2013 - 2018, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
@@ -13,10 +13,11 @@ module within the system.
 """
 
 import decimal
+import simplejson as json
 
 import dateutil.parser as dateutil_parser
 from flask import current_app
-from flask_babel import gettext
+from flask_babelex import gettext
 from flask_security import current_user
 
 from pgadmin.model import db, Preferences as PrefTable, \
@@ -30,8 +31,8 @@ class _Preference(object):
     """
 
     def __init__(
-            self, cid, name, label, _type, default, help_str=None, min_val=None,
-            max_val=None, options=None
+        self, cid, name, label, _type, default, help_str=None,
+        min_val=None, max_val=None, options=None, select2=None, fields=None
     ):
         """
         __init__
@@ -53,6 +54,9 @@ class _Preference(object):
         :param min_val: minimum value
         :param max_val: maximum value
         :param options: options (Array of list objects)
+        :param select2: select2 options (object)
+        :param fields: field schema (if preference has more than one field to
+                        take input from user e.g. keyboardshortcut preference)
 
         :returns: nothing
         """
@@ -65,6 +69,8 @@ class _Preference(object):
         self.min_val = min_val
         self.max_val = max_val
         self.options = options
+        self.select2 = select2
+        self.fields = fields
 
         # Look into the configuration table to find out the id of the specific
         # preference.
@@ -105,7 +111,7 @@ class _Preference(object):
         # The data stored in the configuration will be in string format, we
         # need to convert them in proper format.
         if self._type == 'boolean' or self._type == 'switch' or \
-                        self._type == 'node':
+                self._type == 'node':
             return res.value == 'True'
         if self._type == 'integer':
             try:
@@ -129,10 +135,18 @@ class _Preference(object):
             for opt in self.options:
                 if 'value' in opt and opt['value'] == res.value:
                     return res.value
+            if self.select2 and self.select2['tags']:
+                return res.value
             return self.default
         if self._type == 'text':
             if res.value == '':
                 return self.default
+        if self._type == 'keyboardshortcut':
+            try:
+                return json.loads(res.value)
+            except Exception as e:
+                current_app.logger.exeception(e)
+                return self.default
 
         return res.value
 
@@ -148,7 +162,7 @@ class _Preference(object):
         # We can't store the values in the given format, we need to convert
         # them in string first. We also need to validate the value type.
         if self._type == 'boolean' or self._type == 'switch' or \
-                        self._type == 'node':
+                self._type == 'node':
             if type(value) != bool:
                 return False, gettext("Invalid value for a boolean option.")
         elif self._type == 'integer':
@@ -190,8 +204,16 @@ class _Preference(object):
                 if 'value' in opt and opt['value'] == value:
                     has_value = True
 
-            if not has_value:
+            if not has_value and self.select2 and not self.select2['tags']:
                 return False, gettext("Invalid value for an options option.")
+        elif self._type == 'keyboardshortcut':
+            try:
+                value = json.dumps(value)
+            except Exception as e:
+                current_app.logger.exeception(e)
+                return False, gettext(
+                    "Invalid value for a keyboard shortcut option."
+                )
 
         pref = UserPrefTable.query.filter_by(
             pid=self.pid
@@ -226,7 +248,9 @@ class _Preference(object):
             'min_val': self.min_val,
             'max_val': self.max_val,
             'options': self.options,
-            'value': self.get()
+            'select2': self.select2,
+            'value': self.get(),
+            'fields': self.fields,
         }
         return res
 
@@ -365,7 +389,8 @@ class Preferences(object):
 
     def register(
             self, category, name, label, _type, default, min_val=None,
-            max_val=None, options=None, help_str=None, category_label=None
+            max_val=None, options=None, help_str=None, category_label=None,
+            select2=None, fields=None
     ):
         """
         register
@@ -386,6 +411,9 @@ class Preferences(object):
         :param options:
         :param help_str:
         :param category_label:
+        :param select2: select2 control extra options
+        :param fields: field schema (if preference has more than one field to
+                        take input from user e.g. keyboardshortcut preference)
         """
         cat = self.__category(category, category_label)
         if name in cat['preferences']:
@@ -395,12 +423,13 @@ class Preferences(object):
         assert _type is not None, "Type for a preference cannot be none!"
         assert _type in (
             'boolean', 'integer', 'numeric', 'date', 'datetime',
-            'options', 'multiline', 'switch', 'node', 'text'
+            'options', 'multiline', 'switch', 'node', 'text',
+            'keyboardshortcut'
         ), "Type cannot be found in the defined list!"
 
         (cat['preferences'])[name] = res = _Preference(
             cat['id'], name, label, _type, default, help_str, min_val,
-            max_val, options
+            max_val, options, select2, fields
         )
 
         return res
@@ -473,6 +502,43 @@ class Preferences(object):
             options, help_str, category_label
         )
 
+    @staticmethod
+    def raw_value(_module, _preference, _category=None, _user_id=None):
+        # Find the entry for this module in the configuration database.
+        module = ModulePrefTable.query.filter_by(name=_module).first()
+
+        if module is None:
+            return None
+
+        if _category is None:
+            _category = _module
+
+        if _user_id is None:
+            _user_id = getattr(current_user, 'id', None)
+            if _user_id is None:
+                return None
+
+        cat = PrefCategoryTbl.query.filter_by(
+            mid=module.id).filter_by(name=_category).first()
+
+        if cat is None:
+            return None
+
+        pref = PrefTable.query.filter_by(
+            name=_preference).filter_by(cid=cat.id).first()
+
+        if pref is None:
+            return None
+
+        user_pref = UserPrefTable.query.filter_by(
+            pid=pref.id
+        ).filter_by(uid=_user_id).first()
+
+        if user_pref is not None:
+            return user_pref.value
+
+        return None
+
     @classmethod
     def module(cls, name, create=True):
         """
@@ -512,7 +578,7 @@ class Preferences(object):
         # Can't find the reference for it in the configuration database,
         # create on for it.
         if module is None:
-            return False, gettext("Could not fine the specified module.")
+            return False, gettext("Could not find the specified module.")
 
         m = cls.modules[module.name]
 
@@ -551,7 +617,7 @@ class Preferences(object):
         try:
             pref.set(value)
         except Exception as e:
-            current_app.logger.exeception(e)
+            current_app.logger.exception(e)
             return False, str(e)
 
         return True, None
