@@ -37,14 +37,17 @@ class PgadminPage:
 
     def click_modal(self, button_text):
         time.sleep(0.5)
-        # Find active alertify dialog in case of multiple alertify dialog & click on that dialog
+        # Find active alertify dialog in case of multiple alertify dialog
+        # & click on that dialog
         modal_button = self.find_by_xpath(
-            "//div[contains(@class, 'alertify') and not(contains(@class, 'ajs-hidden'))]//button[.='%s']"
+            "//div[contains(@class, 'alertify') and "
+            "not(contains(@class, 'ajs-hidden'))]//button[.='%s']"
             % button_text)
         self.click_element(modal_button)
 
     def add_server(self, server_config):
-        self.find_by_xpath("//*[@class='aciTreeText' and contains(.,'Servers')]").click()
+        self.find_by_xpath(
+            "//*[@class='aciTreeText' and contains(.,'Servers')]").click()
         self.driver.find_element_by_link_text("Object").click()
         ActionChains(self.driver) \
             .move_to_element(self.driver.find_element_by_link_text("Create")) \
@@ -57,9 +60,13 @@ class PgadminPage:
         self.fill_input_by_field_name("port", server_config['port'])
         self.fill_input_by_field_name("username", server_config['username'])
         self.fill_input_by_field_name("password", server_config['db_password'])
-        self.find_by_xpath("//button[contains(.,'Save')]").click()
+        WebDriverWait(self.driver, 10).until(EC.element_to_be_clickable(
+            (By.CSS_SELECTOR, "button[type='save'].btn.btn-primary")))
+        self.find_by_css_selector("button[type='save'].btn.btn-primary").\
+            click()
 
-        self.find_by_xpath("//*[@id='tree']//*[.='" + server_config['name'] + "']")
+        self.find_by_xpath(
+            "//*[@id='tree']//*[.='" + server_config['name'] + "']")
 
     def open_query_tool(self):
         self.driver.find_element_by_link_text("Tools").click()
@@ -73,7 +80,6 @@ class PgadminPage:
         self.find_by_partial_link_text("Query Tool").click()
         self.click_tab('Query -')
 
-
     def enable_menu_item(self, menu_item, wait_time):
         start_time = time.time()
         # wait until menu becomes enabled.
@@ -89,14 +95,22 @@ class PgadminPage:
         else:
             assert False, "'Tools -> Query Tool' menu did not enable."
 
-    def close_query_tool(self):
+    def close_query_tool(self, name="Query", prompt=True):
         self.driver.switch_to.default_content()
-        tab = self.find_by_xpath("//*[contains(@class,'wcPanelTab') and contains(.,'" + "Query" + "')]")
+        tab = self.find_by_xpath(
+            "//*[contains(@class,'wcPanelTab') and "
+            "contains(.,'" + name + "')]")
         ActionChains(self.driver).context_click(tab).perform()
-        self.find_by_xpath("//li[contains(@class, 'context-menu-item')]/span[contains(text(), 'Remove Panel')]").click()
-        self.driver.switch_to.frame(self.driver.find_elements_by_tag_name("iframe")[0])
-        time.sleep(.5)
-        self.click_element(self.find_by_xpath('//button[contains(@class, "ajs-button") and contains(.,"Don\'t save")]'))
+        self.find_by_xpath(
+            "//li[contains(@class, 'context-menu-item')]/span[contains(text(),"
+            " 'Remove Panel')]").click()
+        if prompt:
+            self.driver.switch_to.frame(
+                self.driver.find_elements_by_tag_name("iframe")[0])
+            time.sleep(.5)
+            self.click_element(self.find_by_xpath(
+                '//button[contains(@class, "ajs-button") and '
+                'contains(.,"Don\'t save")]'))
         self.driver.switch_to.default_content()
 
     def close_data_grid(self):
@@ -106,7 +120,9 @@ class PgadminPage:
 
     def remove_server(self, server_config):
         self.driver.switch_to.default_content()
-        server_to_remove = self.find_by_xpath("//*[@id='tree']//*[.='" + server_config['name'] + "' and @class='aciTreeItem']")
+        server_to_remove = self.find_by_xpath(
+            "//*[@id='tree']//*[.='" + server_config['name'] +
+            "' and @class='aciTreeItem']")
         self.click_element(server_to_remove)
         object_menu_item = self.find_by_partial_link_text("Object")
         self.click_element(object_menu_item)
@@ -115,10 +131,14 @@ class PgadminPage:
         self.click_modal('OK')
 
     def select_tree_item(self, tree_item_text):
-        self.find_by_xpath("//*[@id='tree']//*[.='" + tree_item_text + "' and @class='aciTreeItem']").click()
+        self.find_by_xpath(
+            "//*[@id='tree']//*[.='" + tree_item_text +
+            "' and @class='aciTreeItem']").click()
 
     def toggle_open_tree_item(self, tree_item_text):
-        self.find_by_xpath("//*[@id='tree']//*[.='" + tree_item_text + "']/../*[@class='aciTreeButton']").click()
+        self.find_by_xpath(
+            "//*[@id='tree']//*[.='" + tree_item_text +
+            "']/../*[@class='aciTreeButton']").click()
 
     def toggle_open_server(self, tree_item_text):
         def check_for_password_dialog_or_tree_open(driver):
@@ -128,14 +148,17 @@ class PgadminPage:
                 dialog = None
 
             try:
-                database_node = driver.find_element_by_xpath("//*[@id='tree']//*[.='Databases']/../*[@class='aciTreeButton']")
+                database_node = driver.find_element_by_xpath(
+                    "//*[@id='tree']//*[.='Databases']"
+                    "/../*[@class='aciTreeButton']")
             except WebDriverException:
                 database_node = None
 
             return dialog is not None or database_node is not None
 
         self.toggle_open_tree_item(tree_item_text)
-        self._wait_for("Waiting for password dialog or tree to open", check_for_password_dialog_or_tree_open)
+        self._wait_for("Waiting for password dialog or tree to open",
+                       check_for_password_dialog_or_tree_open)
 
         try:
             self.driver.find_element_by_id("frmPassword")
@@ -145,13 +168,19 @@ class PgadminPage:
             return
 
     def find_by_xpath(self, xpath):
-        return self.wait_for_element(lambda driver: driver.find_element_by_xpath(xpath))
+        return self.wait_for_element(
+            lambda driver: driver.find_element_by_xpath(xpath)
+        )
 
     def find_by_id(self, element_id):
-        return self.wait_for_element(lambda driver: driver.find_element_by_id(element_id))
+        return self.wait_for_element(
+            lambda driver: driver.find_element_by_id(element_id)
+        )
 
     def find_by_css_selector(self, css_selector):
-        return self.wait_for_element(lambda driver: driver.find_element_by_css_selector(css_selector))
+        return self.wait_for_element(
+            lambda driver: driver.find_element_by_css_selector(css_selector)
+        )
 
     def find_by_partial_link_text(self, link_text):
         return self._wait_for(
@@ -160,7 +189,8 @@ class PgadminPage:
         )
 
     def click_element(self, element):
-        # driver must be here to adhere to the method contract in selenium.webdriver.support.wait.WebDriverWait.until()
+        # driver must be here to adhere to the method contract in
+        # selenium.webdriver.support.wait.WebDriverWait.until()
         def click_succeeded(driver):
             try:
                 element.click()
@@ -168,7 +198,9 @@ class PgadminPage:
             except WebDriverException:
                 return False
 
-        return self._wait_for("clicking the element not to throw an exception", click_succeeded)
+        return self._wait_for(
+            "clicking the element not to throw an exception", click_succeeded
+        )
 
     def fill_input_by_field_name(self, field_name, field_content):
         field = self.find_by_xpath("//input[@name='" + field_name + "']")
@@ -183,9 +215,11 @@ class PgadminPage:
         def find_codemirror(driver):
             try:
                 driver.switch_to.default_content()
-                driver.switch_to_frame(driver.find_element_by_tag_name("iframe"))
+                driver.switch_to_frame(
+                    driver.find_element_by_tag_name("iframe"))
                 element = driver.find_element_by_xpath(
-                    "//pre[contains(@class,'CodeMirror-line')]/../../../*[contains(@class,'CodeMirror-code')]")
+                    "//pre[contains(@class,'CodeMirror-line')]/../../../"
+                    "*[contains(@class,'CodeMirror-code')]")
                 if element.is_displayed() and element.is_enabled():
                     return element
             except (NoSuchElementException, WebDriverException):
@@ -193,8 +227,8 @@ class PgadminPage:
 
         time.sleep(1)
         WebDriverWait(self.driver, timeout=self.timeout, poll_frequency=0.01).\
-            until(find_codemirror, "Timed out waiting for codemirror to appear").\
-            click()
+            until(find_codemirror, "Timed out waiting for codemirror "
+                                   "to appear").click()
         time.sleep(1)
 
         action = ActionChains(self.driver)
@@ -202,8 +236,15 @@ class PgadminPage:
         action.perform()
 
     def click_tab(self, tab_name):
-        tab = self.find_by_xpath("//*[contains(@class,'wcTabTop')]//*[contains(@class,'wcPanelTab') "
-                           "and contains(.,'" + tab_name + "')]")
+        WebDriverWait(self.driver, 10).until(EC.element_to_be_clickable(
+            (By.XPATH, "//*[contains(@class,'wcTabTop')]//"
+                       "*[contains(@class,'wcPanelTab') "
+                       "and contains(.,'" + tab_name + "')]")))
+
+        tab = self.find_by_xpath("//*[contains(@class,'wcTabTop')]//"
+                                 "*[contains(@class,'wcPanelTab') "
+                                 "and contains(.,'" + tab_name + "')]")
+
         self.click_element(tab)
 
     def wait_for_input_field_content(self, field_name, content):
@@ -213,7 +254,9 @@ class PgadminPage:
 
             return str(content) == element.get_attribute('value')
 
-        return self._wait_for("field to contain '" + str(content) + "'", input_field_has_content)
+        return self._wait_for(
+            "field to contain '" + str(content) + "'", input_field_has_content
+        )
 
     def wait_for_element(self, find_method_with_args):
         def element_if_it_exists(driver):
@@ -247,7 +290,8 @@ class PgadminPage:
             except NoSuchElementException:
                 return True
 
-        self._wait_for("reloading indicator to disappear", reloading_indicator_has_disappeared)
+        self._wait_for("reloading indicator to disappear",
+                       reloading_indicator_has_disappeared)
 
     def wait_for_spinner_to_disappear(self):
         def spinner_has_disappeared(driver):
@@ -283,8 +327,19 @@ class PgadminPage:
 
         self._wait_for("app to start", page_shows_app, self.app_start_timeout)
 
-    def _wait_for(self, waiting_for_message, condition_met_function, timeout = None):
+    def wait_for_element_to_reload(self, element_selector):
+        WebDriverWait(self.driver, 20) \
+            .until(EC.staleness_of(element_selector(self.driver)))
+        WebDriverWait(self.driver, 20) \
+            .until_not(EC.staleness_of(element_selector(self.driver)))
+
+        return element_selector(self.driver)
+
+    def _wait_for(self, waiting_for_message, condition_met_function,
+                  timeout=None):
         if timeout is None:
             timeout = self.timeout
-        return WebDriverWait(self.driver, timeout, 0.01).until(condition_met_function,
-                                                                    "Timed out waiting for " + waiting_for_message)
+        return WebDriverWait(self.driver, timeout, 0.01).until(
+            condition_met_function,
+            "Timed out waiting for " + waiting_for_message
+        )
